@@ -1,7 +1,6 @@
-from __future__ import absolute_import
-
-from domain.ecm_services import ECMDatasetService
-from interface.ecm_dataset import DatasetQueryParams
+from typing import List
+from pip_middleware_fluig.domain.ecm_services import ECMDatasetService
+from pip_middleware_fluig.interface.ecm_dataset import DatasetQueryParams
 
 
 class FluigECMService:
